//#######################################################################
//#
//#	Copyright 	Earth People Technology Inc. 2012
//#
//#
//# File Name:  ept_2232h_top.v
//# Author:     R. Jolly
//# Date:       March 23, 2012
//# Revision:   A
//#
//# Development: USB Test Tool Interface board 
//# Application: Xilinx Spartan 3
//# Description: This file contains verilog code which will allow access
//#              to an eight bit bus in the FPGA. The FPGA receives its commands via
//#				 USB.
//#               
//#              
//#
//#************************************************************************
//#
//# Revision History:	
//#			DATE		VERSION		DETAILS		
//#			03/23/12 	A			Created			RJJ
//#
//#									
//#
//#######################################################################


//************************************************************************
//* Module Declaration
//************************************************************************

module ept_2232h_top (

	
	input wire                 CLK,
	input wire                 RST,
		
    // UART Signals
	output wire                UART_OUT,
	input wire                 UART_IN,
		
    // FTDI Control Signals
	input wire                 FTDI_RXF,
	input wire                 FTDI_TXE,
    inout wire [7:0]           FTDI_DATA,

	output wire                FTDI_RD,
	output wire                FTDI_WR,
	output wire                FTDI_SI,
	
	//Transceiver Control Signals
	output wire                TR_DIR_1,
	output wire                TR_OE_1,
	
	output wire                TR_DIR_2,
	output wire                TR_OE_2,

	output wire                TR_DIR_3,
	output wire                TR_OE_3,

    // Test signals
	output wire                TEST_SIGNAL_1
	
	);

	
	
//***************************************************************************
//* Internal Signals and Registers Declarations
//***************************************************************************
		
	//Reset Registers
	wire                       reset_n;
	wire                       global_reset;
	
	//Test Signals
	reg [31:0]                 test_counter;
	reg                        test_signal_reg;
	
	
//***************************************************************************
//* 	Signal Assignments	
//***************************************************************************

    assign          reset_n = !RST;
	assign          global_reset = RST;
	
	assign          TR_DIR_1 = 1'b0;
	assign          TR_OE_1 = 1'b0;

	assign          TR_DIR_2 = 1'b0;
	assign          TR_OE_2 = 1'b1;

	assign          TR_DIR_3 = 1'b0;
	assign          TR_OE_3 = 1'b1;

	assign          TEST_SIGNAL_1 = test_signal_reg;
	
//***************************************************************************
//* 	Test Signal	
//***************************************************************************
	always @(posedge CLK or negedge RST)
	begin
	     if(!RST)
		 begin
		     test_counter <= 0;
			 test_signal_reg <= 1'b0;
		 end
		 else
		 begin
		     if( test_counter < 32'h80e8 )
			     test_counter <= test_counter + 1'b1;
			 else
			 begin
			     test_signal_reg <= ~test_signal_reg;
				 test_counter <= 0;
		     end
		 end
	end
//***************************************************************************
//* 	Leaf Instantiations	
//***************************************************************************
 
   uart_tiny_slave UART_SLAVE_CONTROLLER
   (
     .CLK                      (CLK),
     .RST_N                    (global_reset),

     .UART_OUT                 (UART_OUT), //To external UART 
     .UART_IN                  (UART_IN), //From external UART

	.USB_RXF_N                 (FTDI_RXF),
	.USB_TXE_N                 (FTDI_TXE),
	.USB_DATA                  (FTDI_DATA),

	.USB_RD_N                  (FTDI_RD),
	.USB_WR                    (FTDI_WR),
	.USB_SI                    (FTDI_SI)
	 );
   endmodule
